While in ubuntu devices things seems to be working just fine and if a project is a git repo, the portacode project handler detects that and reads git data in real time, for some reason, this doesn't work in proxmox nodes. Instead it shows a project state object as below

{
    "projectFolderPath": "/home/unicom",
    "isGitRepo": false,
    "gitBranch": null,
    "gitStatusSummary": {},
    "gitDetailedStatus": {
        "head_commit_hash": null,
        "staged_changes": [],
        "unstaged_changes": [],
        "untracked_files": []
    },
    "openTabs": [],
    "activeTab": null,
    "expandedFolders": [],
    "items": [
        {
            "name": ".cursor",
            "path": "/home/unicom/.cursor",
            "is_directory": true,
            "parent_path": "/home/unicom",
            "size": null,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": true,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "data",
            "path": "/home/unicom/data",
            "is_directory": true,
            "parent_path": "/home/unicom",
            "size": null,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "tests",
            "path": "/home/unicom/tests",
            "is_directory": true,
            "parent_path": "/home/unicom",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "unibot",
            "path": "/home/unicom/unibot",
            "is_directory": true,
            "parent_path": "/home/unicom",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "unicom",
            "path": "/home/unicom/unicom",
            "is_directory": true,
            "parent_path": "/home/unicom",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": true,
            "is_loaded": true
        },
        {
            "name": "unicom_project",
            "path": "/home/unicom/unicom_project",
            "is_directory": true,
            "parent_path": "/home/unicom",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": true,
            "is_loaded": true
        },
        {
            "name": ".gitignore",
            "path": "/home/unicom/.gitignore",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 251,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": true,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": ".gitmodules",
            "path": "/home/unicom/.gitmodules",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 81,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": true,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "conftest.py",
            "path": "/home/unicom/conftest.py",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 1109,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "docker-compose.yaml",
            "path": "/home/unicom/docker-compose.yaml",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 820,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "Dockerfile",
            "path": "/home/unicom/Dockerfile",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 1197,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "entrypoint.sh",
            "path": "/home/unicom/entrypoint.sh",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 347,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "Makefile",
            "path": "/home/unicom/Makefile",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 584,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "manage.py",
            "path": "/home/unicom/manage.py",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 670,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "MANIFEST.in",
            "path": "/home/unicom/MANIFEST.in",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 289,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "pyproject.toml",
            "path": "/home/unicom/pyproject.toml",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 244,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "pytest.ini",
            "path": "/home/unicom/pytest.ini",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 189,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "README.md",
            "path": "/home/unicom/README.md",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 42562,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "requirements.txt",
            "path": "/home/unicom/requirements.txt",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 588,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "send_test_buttons.py",
            "path": "/home/unicom/send_test_buttons.py",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 1966,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "setup.py",
            "path": "/home/unicom/setup.py",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 1439,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "test_comprehensive_buttons.py",
            "path": "/home/unicom/test_comprehensive_buttons.py",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 10629,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "test_dkim_security.py",
            "path": "/home/unicom/test_dkim_security.py",
            "is_directory": false,
            "parent_path": "/home/unicom",
            "size": 3810,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "rules",
            "path": "/home/unicom/.cursor/rules",
            "is_directory": true,
            "parent_path": "/home/unicom/.cursor",
            "size": null,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "definitions",
            "path": "/home/unicom/data/definitions",
            "is_directory": true,
            "parent_path": "/home/unicom/data",
            "size": null,
            "modified_time": 1760358197.6143548,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/tests/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/tests",
            "size": 0,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "test_email_authentication.py",
            "path": "/home/unicom/tests/test_email_authentication.py",
            "is_directory": false,
            "parent_path": "/home/unicom/tests",
            "size": 10515,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "test_email_live.py",
            "path": "/home/unicom/tests/test_email_live.py",
            "is_directory": false,
            "parent_path": "/home/unicom/tests",
            "size": 3271,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "test_email_request_processing.py",
            "path": "/home/unicom/tests/test_email_request_processing.py",
            "is_directory": false,
            "parent_path": "/home/unicom/tests",
            "size": 12496,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "test_telegram_live.py",
            "path": "/home/unicom/tests/test_telegram_live.py",
            "is_directory": false,
            "parent_path": "/home/unicom/tests",
            "size": 3217,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "utils.py",
            "path": "/home/unicom/tests/utils.py",
            "is_directory": false,
            "parent_path": "/home/unicom/tests",
            "size": 559,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "admin",
            "path": "/home/unicom/unicom/admin",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": true,
            "is_loaded": true
        },
        {
            "name": "management",
            "path": "/home/unicom/unicom/management",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "migrations",
            "path": "/home/unicom/unicom/migrations",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "models",
            "path": "/home/unicom/unicom/models",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "services",
            "path": "/home/unicom/unicom/services",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "static",
            "path": "/home/unicom/unicom/static",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "templates",
            "path": "/home/unicom/unicom/templates",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "views",
            "path": "/home/unicom/unicom/views",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom",
            "size": 102,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "apps.py",
            "path": "/home/unicom/unicom/apps.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom",
            "size": 339,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "signals.py",
            "path": "/home/unicom/unicom/signals.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom",
            "size": 5815,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "urls.py",
            "path": "/home/unicom/unicom/urls.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom",
            "size": 1231,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom/admin/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 1557,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "account_admin.py",
            "path": "/home/unicom/unicom/admin/account_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 315,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "channel_admin.py",
            "path": "/home/unicom/unicom/admin/channel_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 1142,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "chat_admin.py",
            "path": "/home/unicom/unicom/admin/chat_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 7691,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "draft_message_admin.py",
            "path": "/home/unicom/unicom/admin/draft_message_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 11358,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "email_inline_image_admin.py",
            "path": "/home/unicom/unicom/admin/email_inline_image_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 766,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "filters.py",
            "path": "/home/unicom/unicom/admin/filters.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 5689,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "member_admin.py",
            "path": "/home/unicom/unicom/admin/member_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 875,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "message_admin.py",
            "path": "/home/unicom/unicom/admin/message_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 4368,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "message_template_admin.py",
            "path": "/home/unicom/unicom/admin/message_template_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 8350,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "request_admin.py",
            "path": "/home/unicom/unicom/admin/request_admin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/admin",
            "size": 5141,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "commands",
            "path": "/home/unicom/unicom/management/commands",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/management",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom/management/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/management",
            "size": 0,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0001_initial.py",
            "path": "/home/unicom/unicom/migrations/0001_initial.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 23340,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0002_emailinlineimage.py",
            "path": "/home/unicom/unicom/migrations/0002_emailinlineimage.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 931,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0003_alter_emailinlineimage_email_message.py",
            "path": "/home/unicom/unicom/migrations/0003_alter_emailinlineimage_email_message.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 539,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0004_messagetemplateinlineimage.py",
            "path": "/home/unicom/unicom/migrations/0004_messagetemplateinlineimage.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 984,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0005_emailinlineimage_hash_and_more.py",
            "path": "/home/unicom/unicom/migrations/0005_emailinlineimage_hash_and_more.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 1194,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0006_channel_created_at_channel_created_by_and_more.py",
            "path": "/home/unicom/unicom/migrations/0006_channel_created_at_channel_created_by_and_more.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 1148,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0007_message_imap_uid.py",
            "path": "/home/unicom/unicom/migrations/0007_message_imap_uid.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 486,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0008_add_all_members_group.py",
            "path": "/home/unicom/unicom/migrations/0008_add_all_members_group.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 1191,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0009_add_tool_call_types.py",
            "path": "/home/unicom/unicom/migrations/0009_add_tool_call_types.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 560,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0010_request_initial_request_request_llm_calls_count_and_more.py",
            "path": "/home/unicom/unicom/migrations/0010_request_initial_request_request_llm_calls_count_and_more.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 3079,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0011_toolcall_add_message_reference.py",
            "path": "/home/unicom/unicom/migrations/0011_toolcall_add_message_reference.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 1050,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0012_message_response_to_tool_call_and_more.py",
            "path": "/home/unicom/unicom/migrations/0012_message_response_to_tool_call_and_more.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 3335,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0013_callbackexecution.py",
            "path": "/home/unicom/unicom/migrations/0013_callbackexecution.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 1669,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0014_rename_authorized_user_to_intended_account.py",
            "path": "/home/unicom/unicom/migrations/0014_rename_authorized_user_to_intended_account.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 410,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0015_simplify_callback_execution.py",
            "path": "/home/unicom/unicom/migrations/0015_simplify_callback_execution.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 2242,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "0016_callbackexecution_tool_call.py",
            "path": "/home/unicom/unicom/migrations/0016_callbackexecution_tool_call.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 628,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom/migrations/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/migrations",
            "size": 0,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom/models/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 814,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "account.py",
            "path": "/home/unicom/unicom/models/account.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 1096,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "account_chat.py",
            "path": "/home/unicom/unicom/models/account_chat.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 374,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "callback_execution.py",
            "path": "/home/unicom/unicom/models/callback_execution.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 1850,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "channel.py",
            "path": "/home/unicom/unicom/models/channel.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 5753,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "chat.py",
            "path": "/home/unicom/unicom/models/chat.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 6719,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "constants.py",
            "path": "/home/unicom/unicom/models/constants.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 109,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "draft_message.py",
            "path": "/home/unicom/unicom/models/draft_message.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 6012,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "fields.py",
            "path": "/home/unicom/unicom/models/fields.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 2510,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "member.py",
            "path": "/home/unicom/unicom/models/member.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 2102,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "member_group.py",
            "path": "/home/unicom/unicom/models/member_group.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 737,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "message.py",
            "path": "/home/unicom/unicom/models/message.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 29594,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "message_template.py",
            "path": "/home/unicom/unicom/models/message_template.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 7960,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "request.py",
            "path": "/home/unicom/unicom/models/request.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 22591,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "request_category.py",
            "path": "/home/unicom/unicom/models/request_category.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 4202,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "tool_call.py",
            "path": "/home/unicom/unicom/models/tool_call.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 6946,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "update.py",
            "path": "/home/unicom/unicom/models/update.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/models",
            "size": 710,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "crossplatform",
            "path": "/home/unicom/unicom/services/crossplatform",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/services",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "email",
            "path": "/home/unicom/unicom/services/email",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/services",
            "size": null,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "internal",
            "path": "/home/unicom/unicom/services/internal",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/services",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "llm",
            "path": "/home/unicom/unicom/services/llm",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/services",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "telegram",
            "path": "/home/unicom/unicom/services/telegram",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/services",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "whatsapp",
            "path": "/home/unicom/unicom/services/whatsapp",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/services",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom/services/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/services",
            "size": 0,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "chat_summary.py",
            "path": "/home/unicom/unicom/services/chat_summary.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/services",
            "size": 1622,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "decode_base64_image.py",
            "path": "/home/unicom/unicom/services/decode_base64_image.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/services",
            "size": 1087,
            "modified_time": 1760358197.618355,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "get_public_origin.py",
            "path": "/home/unicom/unicom/services/get_public_origin.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/services",
            "size": 441,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "html_inline_images.py",
            "path": "/home/unicom/unicom/services/html_inline_images.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/services",
            "size": 4586,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "unicom",
            "path": "/home/unicom/unicom/static/unicom",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/static",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "admin",
            "path": "/home/unicom/unicom/templates/admin",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/templates",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "code_templates",
            "path": "/home/unicom/unicom/templates/code_templates",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom/templates",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom/views/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 0,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "chat_history_view.py",
            "path": "/home/unicom/unicom/views/chat_history_view.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 4330,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "compose_view.py",
            "path": "/home/unicom/unicom/views/compose_view.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 6503,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "email_tracking.py",
            "path": "/home/unicom/unicom/views/email_tracking.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 4881,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "inline_image.py",
            "path": "/home/unicom/unicom/views/inline_image.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 1451,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "message_template.py",
            "path": "/home/unicom/unicom/views/message_template.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 2757,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "telegram_webhook.py",
            "path": "/home/unicom/unicom/views/telegram_webhook.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 2775,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "whatsapp_webhook.py",
            "path": "/home/unicom/unicom/views/whatsapp_webhook.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom/views",
            "size": 2834,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "definitions",
            "path": "/home/unicom/unicom_project/definitions",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom_project",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom_project/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 62,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "apps.py",
            "path": "/home/unicom/unicom_project/apps.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 292,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "asgi.py",
            "path": "/home/unicom/unicom_project/asgi.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 405,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "callback_handlers.py",
            "path": "/home/unicom/unicom_project/callback_handlers.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 8507,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "settings.py",
            "path": "/home/unicom/unicom_project/settings.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 4850,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "test_button_handlers.py",
            "path": "/home/unicom/unicom_project/test_button_handlers.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 6687,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "urls.py",
            "path": "/home/unicom/unicom_project/urls.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 1023,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "wsgi.py",
            "path": "/home/unicom/unicom_project/wsgi.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project",
            "size": 405,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        },
        {
            "name": "bots",
            "path": "/home/unicom/unicom_project/definitions/bots",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom_project/definitions",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "tools",
            "path": "/home/unicom/unicom_project/definitions/tools",
            "is_directory": true,
            "parent_path": "/home/unicom/unicom_project/definitions",
            "size": null,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": false
        },
        {
            "name": "__init__.py",
            "path": "/home/unicom/unicom_project/definitions/__init__.py",
            "is_directory": false,
            "parent_path": "/home/unicom/unicom_project/definitions",
            "size": 0,
            "modified_time": 1760358197.6223552,
            "is_git_tracked": false,
            "git_status": null,
            "is_staged": false,
            "is_hidden": false,
            "is_ignored": false,
            "children": null,
            "is_expanded": false,
            "is_loaded": true
        }
    ],
    "timestamp": 1760358848.676952
}